@@ -12,11 +12,11 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import io
 import sys
 from unittest import mock
 
 from keystoneauth1 import exceptions
-import six
 import testtools
 
 from aodhclient import shell
@@ -24,7 +24,7 @@ from aodhclient import shell
 
 class CliTest(testtools.TestCase):
 
-    @mock.patch('sys.stderr', six.StringIO())
+    @mock.patch('sys.stderr', io.StringIO())
     def test_cli_http_error_with_details(self):
         shell.AodhShell().clean_up(
             None, None, exceptions.HttpError('foo', details='bar'))
@@ -32,7 +32,7 @@ class CliTest(testtools.TestCase):
         self.assertEqual(1, len(stderr_lines))
         self.assertEqual('bar', stderr_lines[0])
 
-    @mock.patch('sys.stderr', six.StringIO())
+    @mock.patch('sys.stderr', io.StringIO())
     def test_cli_http_error_without_details(self):
         shell.AodhShell().clean_up(None, None, exceptions.HttpError('foo'))
         stderr_lines = sys.stderr.getvalue().splitlines()
