@@ -1,4 +1,3 @@
-# -*- encoding: utf-8 -*-
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
@@ -12,20 +11,20 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 import re
-from six.moves.urllib import parse as urllib_parse
+from urllib import parse as urllib_parse
 
 import pyparsing as pp
 
 uninary_operators = ("not", )
-binary_operator = (u">=", u"<=", u"!=", u">", u"<", u"=", u"==", u"eq", u"ne",
-                   u"lt", u"gt", u"ge", u"le")
-multiple_operators = (u"and", u"or")
+binary_operator = (">=", "<=", "!=", ">", "<", "=", "==", "eq", "ne",
+                   "lt", "gt", "ge", "le")
+multiple_operators = ("and", "or")
 
-operator = pp.Regex(u"|".join(binary_operator))
+operator = pp.Regex("|".join(binary_operator))
 null = pp.Regex("None|none|null").setParseAction(pp.replaceWith(None))
 boolean = "False|True|false|true"
 boolean = pp.Regex(boolean).setParseAction(lambda t: t[0].lower() == "true")
-hex_string = lambda n: pp.Word(pp.hexnums, exact=n)
+hex_string = lambda n: pp.Word(pp.hexnums, exact=n)  # noqa: E731
 uuid = pp.Combine(hex_string(8) + ("-" + hex_string(4)) * 3 +
                   "-" + hex_string(12))
 number = r"[+-]?\d+(:?\.\d*)?(:?[eE][+-]?\d+)?"
@@ -40,7 +39,7 @@ comparison_term << (null | boolean | uuid | identifier | number |
                     quoted_string)
 condition = pp.Group(comparison_term + operator + comparison_term)
 
-expr = pp.operatorPrecedence(condition, [
+expr = pp.infixNotation(condition, [
     ("not", 1, pp.opAssoc.RIGHT, ),
     ("and", 2, pp.opAssoc.LEFT, ),
     ("or", 2, pp.opAssoc.LEFT, ),
@@ -104,14 +103,14 @@ def format_string_list(objs, field):
 
 def format_dict_list(objs, field):
     objs[field] = "\n".join(
-        "- " + ", ".join("%s: %s" % (k, v)
+        "- " + ", ".join("{}: {}".format(k, v)
                          for k, v in elem.items())
         for elem in objs[field])
 
 
 def format_move_dict_to_root(obj, field):
     for attr in obj[field]:
-        obj["%s/%s" % (field, attr)] = obj[field][attr]
+        obj["{}/{}".format(field, attr)] = obj[field][attr]
     del obj[field]
 
 
@@ -131,12 +130,19 @@ def dict_from_parsed_args(parsed_args, attrs):
         else:
             value = getattr(parsed_args, attr)
         if value is not None:
-            d[attr] = value
+            if value == [""]:
+                # NOTE(jake): As options like --alarm-actions is an array,
+                # their value can be array with empty string if user set option
+                # to ''. In this case we set it to None here so that a None
+                # value gets sent to API.
+                d[attr] = None
+            else:
+                d[attr] = value
     return d
 
 
 def dict_to_querystring(objs):
-    return "&".join(["%s=%s" % (k, v)
+    return "&".join(["{}={}".format(k, v)
                      for k, v in objs.items()
                      if v is not None])
 
